// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// -*-C++-*-
//
// File:      Dll.cc
// Author:    jbakker
// Generated: Wed Apr 26 13:47:00 MET DST 2000

#include "Dll.h"
#include <dlfcn.h>

Dll::Dll() 
  : _name(""),_errmsg(""),_handle(0)
{
}

Dll::Dll(const string& library) 
  : _name(library),_errmsg(""),_handle(0)
{
  open(_name);
}

Dll::~Dll()
{
  close();
}


bool Dll::open(const string& library)
{
  close();
  _name=library;
  _handle = dlopen(_name.c_str(), RTLD_LAZY);

  if ( !_handle ) {
    _errmsg=dlerror();
    return false;
  }
  else return true;
}

void Dll::close()
{
  if (_handle) dlclose(_handle);
  _errmsg = "";
}

void *Dll::function(const string& name)
{
  void *fn=0;
  string fname = name;
  fn=dlsym(_handle, fname.c_str());
  // On Mac OS X dlsym and company are available through a wrapper
  // around the native interface. This wrapper is provided by the
  // finch project. The problem is that it is not always guaranteed
  // that the dlsym puts an underscore in front of the symbol
  // names. This can be configure at build time (of the wrapper in
  // question). To make life easier, and avoid surprises in case the
  // SAS is built on a system with the _ and run on a system without
  // it (or vice versa), here we try to load a symbol twice, once
  // without the underscore, and once with it. Only if both attempts
  // fail is an error issued.
  if (fn == 0) {
    fname = "_" + fname;
    fn=dlsym(_handle, fname.c_str());
    if (fn == 0) _errmsg=dlerror();
  }

  return fn;
}
