// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// -*-C++-*-
//
// File:      Dll.h
// Author:    jbakker
// Generated: Wed Apr 26 13:39:09 MET DST 2000

#ifndef Dll_h
#define Dll_h

#include <string>

/*
  Provides an interface to use dynamic linked libraries at runtime

  Example:
    // /usr/local/libFoo.so: int doSomething(int);

    Dll dll("/usr/local/libFoo.so");
    if (dll.valid()) {
      typedef int (*DLLFUNCTION)(int);
      DLLFUNCTION pDoSomething=(DLLFUNCTION)dll.function("doSomething");
      if (pDoSomething) {
         cout << (*pDoSomething)(123) << endl;
      }
    }
  
 */
class Dll
{
public:
  Dll();

  // constructor that opens a library
  Dll(const string& library);
  virtual ~Dll();

  // open a library.
  bool open(const string& library);
  void close();

  // opens the library, returns NULL if function does not exist
  void *function(const string& name);

  bool valid() {return (_errmsg.empty());}

  // returns last error
  const string& error() {return _errmsg;}

protected:
  // only derived classes can use these

private:
  // member functions
  Dll(const Dll&);            // copy constructor (disabled)
  Dll& operator=(const Dll&); // assignment (disabled)

  // member data
  string _name;
  string _errmsg;
  void  *_handle;
};



#endif
