// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// -*-C++-*-
//
// File:      HelpViewer.cc
// Author:    jbakker
// Generated: Tue Apr 11 16:05:28 MET DST 2000

#include "HelpViewer.h"
#include <errstr.h>

#include <iostream>
#include <cstdlib>                 // C headers

/* all instances in a single session use the same browser */
static bool isConfigured=false;
static std::string theBrowser("netscape"); // fall-back...

HelpViewer::HelpViewer()
{
}

HelpViewer::~HelpViewer()
{
}

std::string HelpViewer::browser() const
{
  if (!isConfigured) {

    if(std::getenv("SAS_BROWSER"))
      theBrowser = std::getenv("SAS_BROWSER");
    else // assume default
      theBrowser = "netscape";
    isConfigured=true;
  }
  
  return theBrowser;
}

bool HelpViewer::browse(const std::string& url)
{  

  /* remote only works for netscape4 ;-( */
  std::string remote(browser() + " -remote \"openURL(" + url + ")\"");
  std::string launch(browser() + " " + url + "&");

  if ( std::system(remote.c_str()) /*failed*/ ) {

    // fall back?
    errstr << "Trying to start " << theBrowser << " in the background ...";
    if ( std::system(launch.c_str()) /*failed*/ ) {
      errstr << "failed." << Sas::message(Msg::App, Msg::Always);
      return false;
    }
    else 
      errstr << "ok." << Sas::message(Msg::App, Msg::Always);
  }
  
  return true;
}
