// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// -*-C++-*-
//
// File:      QtRegister.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue Dec 10 15:13:27 CET 2002
// Usage:     -
// Info:      -

#include "QtRegister.h"
#include <qapplication.h>
#include <cstdlib>
using namespace Info;

QtRegister::QtRegister(Task* t)  :Register(t), _qApp(0), _argv(0),_argc(1)
{
  _argv=new char* [1];
  _argv[0]=(char*)_task->name();
}

QtRegister::~QtRegister()
{
  stop();
  delete _argv;
}

void QtRegister::start() {
  // create a default Qt application, if non available
  if (! qApp) {
    /* SOC-SPR-2383

       QApplication(int& argc,char** argv,bool GUIenabled) says [v2.3.2]:
       On X11, the window system is initialized if GUIenabled is TRUE. If
       GUIenabled is FALSE, the application does not connect to the X-server.

       Hmm, it sounds as if a check for X-server availablility is made at
       construction, so we try to avoid the check...
     */
    /* SOC-SPR-2398

       Oops, but if FALSE and you *have* a widget, the whole thing
       collapses, so we check for DISPLAY
     */

    bool isEnabled=true;
#ifdef Q_WS_X11
    isEnabled=(getenv("DISPLAY") !=0);
#endif
    _qApp=new QApplication(_argc,_argv,isEnabled);
  }
}

void QtRegister::stop() {
  if (_qApp) {
    delete _qApp;
    _qApp=0;
  }
}
