// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// -*-C++-*-
//
// File:      Register.h
// Author:    jbakker
// Generated: Mon Apr 10 14:33:24 MET DST 2000

#ifndef Register_h
#define Register_h

#include "Task.h"

namespace Info
{

  /*
    Base class of all registers. Defines what needs to be done
    before/after a call to a particular task.
   */
  class Register
  {
  public:
    virtual ~Register(){}
    
    virtual void start()=0;
    virtual void stop()=0;
    
  protected:
    Register(Task* t) : _task(t){}

    // member data
    Task* _task;

  private:
    // member functions
    Register();
    Register(const Register&);            // copy constructor (disabled)
    Register& operator=(const Register&); // assignment (disabled)    
  };
  
};

#endif
