// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// -*-C++-*-
//
// File:      TaskInfo.h
// Author:    jbakker
// Generated: Mon Mar 27 11:57:05 MET DST 2000

#ifndef Task_h
#define Task_h

#include <param.h>
#include <cstdlib>

extern "C" {
typedef void (*Routine)();
}

namespace Info
{
  class Register;
  class ServerRegistry;

  /**
     Provides information about a task

     It allows execution of the task
   */
  class Task
  {
  public:
    Task(const char* name,const char* version, 
	 const char* release, const char* package, Routine);
    virtual ~Task();
    
    const char* name()    const {return _name;}
    const char* version() const {return _version;}
    const char* release() const {return _release;}
    const char* package() const {return _package;}

    // By default, the task is executed as routine, else as child process
    void        exec(bool invoke=false);

    template<class T>
    void setParameter(const string& name, const T& value) {
      paramToTask();
      ::setParameter(name,value);
      paramToGlobal();
    }

    ParameterInfo* parameters() {
      paramToTask();      
      paramToGlobal();
      return _param;
    }

    Routine method() {return _method;}


    // during execution, a task may query itself...
    static Task* current() {return _current;}
  protected:
    // only derived classes can use these


    /*
      adds a Register to this task (DAL,Qt etc...)
     */
    void append(Register*);
    
  private:
    // member functions
    Task();                           // default constructor (disabled)
    Task(const Task&);            // copy constructor (disabled)
    Task& operator=(const Task&); // assignment (disabled)
    
    void paramToTask();
    void paramToGlobal();

    void subscribe();
    void unsubscribe();

    // member data
    const char*     _name;
    const char*     _version;
    const char*     _release;
    const char*     _package;
    ParameterInfo*  _param;
    ParameterInfo*  _global;
    Routine         _method;

    ServerRegistry* _registry;

    static Task*    _current;
  };

};

/**
   Queries availability of a task, and returns a pointer to Task object.
   If the task does not exists, NULL is returned.
*/
Info::Task* task(const char* name);

// backwards compatibility
void task(Routine);

#endif
