// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#include "metatask.h"
#include <Handle.h>
#include <f90cxx.h>
#include <stringutil.h>
#include <cstdio>
#include <cstring>

F90PROCDEF(void,task)(Routine t)
{
  task(t);
}

F90PROCDEF(Handle<Info::Task>,gettaskinfo)
  (const char * name,int nameLength)
{
  Info::Task* t=0;
  if (name) {
    string n=trim(string(name,nameLength));
    t=task(n.c_str());
  }
  else  t=Info::Task::current();

  return t;
}

F90PROCDEF(void,taskinfoname)
  (char * name,int nameLength,const Handle<Info::Task > & h)
{
  string n =trim(string(name,nameLength));

  Info::Task* t=h.addressOfObject();
  //sprintf(name,"%-*.*s",nameLength,nameLength,t->name());

  // AI: Notice that F90 is asking for 256 char len and the index  
  // in C++ starts in 0, while in F90 starts in 1... So therefore, we have to pass
  // to F90 255 char len... Or we have to do what it's written below..
  const int len = min( int(strlen(t->name()) ), nameLength );
  memcpy( name, t->name(), len );
  memset( name + len, ' ', nameLength - len );

}

F90PROCDEF(void,taskinfoversion)
  (char * name,int nameLength,const Handle<Info::Task>& h)
{
  Info::Task* t=h.addressOfObject();
  //sprintf(name,"%-*.*s",nameLength,nameLength,t->version());

  const int len = min( int(strlen(t->name()) ), nameLength );
  memcpy( name, t->name(), len );
  memset( name + len, ' ', nameLength - len );

}

F90PROCDEF(void,taskinfopackage)
  (char * name,int nameLength,const Handle<Info::Task>& h)
{
  Info::Task* t=h.addressOfObject();
  //sprintf(name,"%-*.*s",nameLength,nameLength,t->package());
  
  const int len = min( int(strlen(t->name()) ), nameLength );
  memcpy( name, t->name(), len );
  memset( name + len, ' ', nameLength - len );


}

F90PROCDEF(void,taskinforelease)
  (char * name,int nameLength,const Handle<Info::Task>& h)
{
  Info::Task* t=h.addressOfObject();
  //sprintf(name,"%-*.*s",nameLength,nameLength,t->release());
  
  const int len = min( int(strlen(t->name()) ), nameLength );
  memcpy( name, t->name(), len );
  memset( name + len, ' ', nameLength - len );


}
