! ESA (C) 2000-2018 
!
! This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
!
!    SAS is free software: you can redistribute it and/or modify
!    it under the terms of the GNU General Public License as published by
!    the Free Software Foundation, either version 3 of the License, or
!    (at your option) any later version.
!
!    SAS is distributed in the hope that it will be useful,
!    but WITHOUT ANY WARRANTY; without even the implied warranty of
!    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!    GNU General Public License for more details.
!
!    You should have received a copy of the GNU General Public License
!    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
! Usage:
! ======
!   use metatask_mod
!
!   character(256) :: txt
!   type(TaskInfo) :: t
!
!   ! construction
!   t = getTaskInfo()                ! returns Info about current task
!   t = getTaskInfo(nameOfChildTask) ! returns Info about named task
!
!   txt = nameOf(t)
!   txt = versionOf(t)
!   txt = releaseOf(t)
!   txt = packageOf(t)
module metatask_mod
   use taskinfo_
   implicit none

   private
   public :: TaskInfo ! inherited

   ! << private stuff

   interface

      subroutine task(subtask)
         interface
            subroutine subtask
            end subroutine subtask
         end interface
      end subroutine task

      function getTaskInfo(name)
         use taskinfo_
         character(*),  intent(in),optional  :: name 
         type(TaskInfo)                      :: getTaskInfo
      end function getTaskInfo

      function taskInfoName(t)
         use taskinfo_
         type(TaskInfo), intent(in)  :: t
         character(len=charLength)   :: TaskInfoName
      end function taskInfoName

      function taskInfoVersion(t)
         use taskinfo_
         type(TaskInfo), intent(in)  :: t
         character(len=charLength)   :: TaskInfoVersion
      end function taskInfoVersion

      function taskInfoRelease(t)
         use taskinfo_
         type(TaskInfo), intent(in)  :: t
         character(len=charLength)   :: TaskInfoRelease
      end function taskInfoRelease

      function taskInfoPackage(t)
         use taskinfo_
         type(TaskInfo), intent(in)  :: t
         character(len=charLength)   :: TaskInfoPackage
      end function taskInfoPackage
   end interface
   ! private stuff >>


   ! << public interface
   public :: task
   public :: getTaskInfo

   public :: nameOf
   interface nameOf
      module procedure name_
   end interface

   public :: versionOf
   interface versionOf
      module procedure version_
   end interface

   public :: releaseOf
   interface releaseOf
      module procedure release_
   end interface

   public :: packageOf
   interface packageOf
      module procedure package_
   end interface
   ! public >>
contains

   function name_(t) result(txt)
      type(TaskInfo), intent(in)  :: t
      character(len=charLength)   :: txt

      txt = TaskInfoName(t)
   end function name_

   function version_(t) result(txt)
      type(TaskInfo), intent(in)  :: t
      character(len=charLength)   :: txt
      txt = TaskInfoVersion(t)
   end function version_

   function release_(t) result(txt)
      type(TaskInfo), intent(in)  :: t
      character(len=charLength)   :: txt
      txt = TaskInfoRelease(t)
   end function release_

   function package_(t) result(txt)
      type(TaskInfo), intent(in)  :: t
      character(len=charLength)   :: txt
      txt = TaskInfoPackage(t)
   end function package_

end module metatask_mod
