#! /usr/bin/env python
#
# ESA (C) 2000-2018 
#
# This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
#
#    SAS is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    SAS is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#

# main for SAS python based tasks -----------------------------------------------------------------------

import sys
from param import OptionValues

# Variables name, VERSION, RELEASE and AKA are set to their real names
# at build time by replacing keywords 'taskname', 'version', 'release' and 
# 'aka'.
# Variables that will be changed by the Makefile

name = "-taskname-"
VERSION = "-version-"
RELEASE = "-release-"
AKA = "-aka-"


## ------------------------------------------------------------------------------------------------------
##
## Common options to all SAS tasks:
##
## -a|--ccfpath <dir1>[:<dir2>...] --> SAS_CCFPATH
## -f|--ccffiles <f1> [<f2>...]    --> Not implemented
## -c|--noclobber                  --> SAS_CLOBBER
## -d|--dialog                     --> GUI tool, sasdialog
## -h|--help                       --> param tool, listparams
## -i|--ccf <cif>                  --> SAS_CCF, CIF file
## -m|--manpage                    --> Web browser, sashelp
## -o|--odf <sumfile>              --> SAS_ODF, summary file
## -V|--verbosity <level>          --> SAS_VERBOSITY
## -v|--version                    --> Version of task
##

# Main SAS options
short_opts = 'a:cdhi:mo:V:vw:'
long_opts  = ['ccfpath=', 
              'noclobber', 
	      'dialog', 
	      'help', 
              'ccf=', 
	      'manpage', 
	      'odf=', 
	      'verbosity=', 
	      'version', 
	      'warning=']

task = { 'name'    : name,
         'VERSION' : VERSION,
	 'RELEASE' : RELEASE,
	 'AKA'     : AKA
       }

arguments  = sys.argv

parameters = OptionValues( task       = task,
                           args       = arguments, 
                           short_opts = short_opts,
			   long_opts  = long_opts,
			   usage=False, error={}, opts_and_values=[] )

# End main for SAS python based tasks -------------------------------------

#
